@@ -6,7 +6,7 @@ from transformers import (
     AutoModelWithLMHead,
 )
 import torch
-from jaseci.actions.live_actions import jaseci_action
+from jaseci.jsorc.live_actions import jaseci_action
 import traceback
 from fastapi import HTTPException
 from typing import List, Union
@@ -110,6 +110,6 @@ def train(
 
 
 if __name__ == "__main__":
-    from jaseci.actions.remote_actions import launch_server
+    from jaseci.jsorc.remote_actions import launch_server
 
     launch_server(port=8000)
