@@ -1,6 +1,6 @@
 import os
 import openai
-from jaseci.actions.live_actions import jaseci_action
+from jaseci.jsorc.live_actions import jaseci_action
 import traceback
 from fastapi import HTTPException
 
@@ -37,6 +37,6 @@ def generate(text: str, args: dict = DEFAULT_ARGS):
 
 
 if __name__ == "__main__":
-    from jaseci.actions.remote_actions import launch_server
+    from jaseci.jsorc.remote_actions import launch_server
 
     launch_server(port=8000)
